Module: Google::Apis::AgentregistryV1alpha

Defined in:
lib/google/apis/agentregistry_v1alpha.rb,
lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/service.rb,
lib/google/apis/agentregistry_v1alpha/gem_version.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb

Overview

Agent Registry API

Agent Registry is a centralized, unified catalog that lets you store, discover, and govern Model Context Protocol (MCP) servers, tools, and AI agents within Google Cloud.

Defined Under Namespace

Classes: Agent, AgentRegistryService, AgentSpec, Annotations, AuthProviderBinding, Binding, CancelOperationRequest, Card, Empty, Endpoint, EndpointSpec, FetchAvailableBindingsResponse, Interface, ListAgentsResponse, ListBindingsResponse, ListEndpointsResponse, ListLocationsResponse, ListMcpServersResponse, ListOperationsResponse, ListServicesResponse, Location, McpServer, McpServerSpec, Operation, OperationMetadata, Protocol, SearchAgentsRequest, SearchAgentsResponse, SearchMcpServersRequest, SearchMcpServersResponse, Service, Skill, Source, Status, Target, Tool

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-agentregistry_v1alpha gem

"0.2.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260408"
VERSION =

Version of the Agent Registry API this client connects to. This is NOT the gem version.

'V1alpha'
AUTH_AGENTREGISTRY_READ_ONLY =

See your Google Cloud Agent Registry data and the email address of your Google Account

'https://www.googleapis.com/auth/agentregistry.read-only'
AUTH_AGENTREGISTRY_READ_WRITE =

See, edit, configure, and delete your Google Cloud Agent Registry data and see the email address for your Google Account

'https://www.googleapis.com/auth/agentregistry.read-write'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'
AUTH_CLOUD_PLATFORM_READ_ONLY =

View your data across Google Cloud services and see the email address of your Google Account

'https://www.googleapis.com/auth/cloud-platform.read-only'