Class: Google::Apis::AgentregistryV1alpha::AgentRegistryService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::AgentregistryV1alpha::AgentRegistryService
- Defined in:
- lib/google/apis/agentregistry_v1alpha/service.rb
Overview
Agent Registry API
Agent Registry is a centralized, unified catalog that lets you store, discover, and govern Model Context Protocol (MCP) servers, tools, and AI agents within Google Cloud.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://agentregistry.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_binding(parent, binding_object = nil, binding_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Creates a new Binding in a given project and location.
-
#create_project_location_service(parent, service_object = nil, request_id: nil, service_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Creates a new Service in a given project and location.
-
#create_project_location_skill(parent, skill_object = nil, request_id: nil, skill_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
========================================================================= # Skills Collection APIs Creates a Skill resource container, optionally publishing the initial SkillRevision inline in a single, atomic CRUD roundtrip.
-
#create_project_location_skill_revision(parent, skill_revision_object = nil, request_id: nil, skill_revision_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Creates a new immutable revision and triggers validation pipelines.
-
#delete_project_location_binding(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Deletes a single Binding.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Empty
Deletes a long-running operation.
-
#delete_project_location_service(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Deletes a single Service.
-
#delete_project_location_skill(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Deletes a Skill container along with all its revisions.
-
#delete_project_location_skill_revision(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Deletes a specific revision (restricted to admins to purge accidentally committed secrets).
-
#fetch_project_location_binding_available(parent, page_size: nil, page_token: nil, source_identifier: nil, target_identifier: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::FetchAvailableBindingsResponse
Fetches available Bindings.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Location
Gets information about a location.
-
#get_project_location_agent(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Agent
Gets details of a single Agent.
-
#get_project_location_binding(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Binding
Gets details of a single Binding.
-
#get_project_location_endpoint(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Endpoint
Gets details of a single Endpoint.
-
#get_project_location_mcp_server(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::McpServer
Gets details of a single McpServer.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_publisher(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Publisher
Fetches details of a specific Publisher.
-
#get_project_location_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Service
Gets details of a single Service.
-
#get_project_location_skill(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Skill
Fetches the active configuration and metadata of a Skill.
-
#get_project_location_skill_revision(name, fields: nil, quota_user: nil, download_dest: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::SkillRevision
Gets details of a single immutable Revision.
-
#initialize ⇒ AgentRegistryService
constructor
A new instance of AgentRegistryService.
-
#list_project_location_agents(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListAgentsResponse
Lists Agents in a given project and location.
-
#list_project_location_bindings(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListBindingsResponse
Lists Bindings in a given project and location.
-
#list_project_location_endpoints(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListEndpointsResponse
Lists Endpoints in a given project and location.
-
#list_project_location_mcp_servers(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListMcpServersResponse
Lists McpServers in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_publishers(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListPublishersResponse
Lists all Publishers in a location.
-
#list_project_location_services(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListServicesResponse
Lists Services in a given project and location.
-
#list_project_location_skill_revisions(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListSkillRevisionsResponse
Lists all revisions belonging to a parent Skill.
-
#list_project_location_skills(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListSkillsResponse
Lists logical Skills available in a project.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_binding(name, binding_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Updates the parameters of a single Binding.
-
#patch_project_location_service(name, service_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Updates the parameters of a single Service.
-
#patch_project_location_skill(name, skill_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Updates Skill metadata or overrides active pointers/state using REST standard PATCH.
-
#search_agents(parent, search_agents_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::SearchAgentsResponse
Searches Agents in a given project and location.
-
#search_mcp_servers(parent, search_mcp_servers_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::SearchMcpServersResponse
Searches McpServers in a given project and location.
-
#search_project_location_skills(parent, filter: nil, page_size: nil, page_token: nil, search_string: nil, search_type: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::SearchSkillsResponse
Custom deep-search method to filter by frontmatter or query SKILL.md text blobs.
Constructor Details
#initialize ⇒ AgentRegistryService
Returns a new instance of AgentRegistryService.
49 50 51 52 53 54 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 49 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-agentregistry_v1alpha', client_version: Google::Apis::AgentregistryV1alpha::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
42 43 44 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 42 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
47 48 49 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 47 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
734 735 736 737 738 739 740 741 742 743 744 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 734 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+name}:cancel', ) command.request_representation = Google::Apis::AgentregistryV1alpha::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::AgentregistryV1alpha::Empty::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_binding(parent, binding_object = nil, binding_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Creates a new Binding in a given project and location.
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 287 def create_project_location_binding(parent, binding_object = nil, binding_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/bindings', ) command.request_representation = Google::Apis::AgentregistryV1alpha::Binding::Representation command.request_object = binding_object command.response_representation = Google::Apis::AgentregistryV1alpha::Operation::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['bindingId'] = binding_id unless binding_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_service(parent, service_object = nil, request_id: nil, service_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Creates a new Service in a given project and location.
964 965 966 967 968 969 970 971 972 973 974 975 976 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 964 def create_project_location_service(parent, service_object = nil, request_id: nil, service_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/services', ) command.request_representation = Google::Apis::AgentregistryV1alpha::Service::Representation command.request_object = service_object command.response_representation = Google::Apis::AgentregistryV1alpha::Operation::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['serviceId'] = service_id unless service_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_skill(parent, skill_object = nil, request_id: nil, skill_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
========================================================================= # Skills Collection APIs Creates a Skill resource container, optionally publishing the initial SkillRevision inline in a single, atomic CRUD roundtrip.
1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 1179 def create_project_location_skill(parent, skill_object = nil, request_id: nil, skill_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/skills', ) command.request_representation = Google::Apis::AgentregistryV1alpha::Skill::Representation command.request_object = skill_object command.response_representation = Google::Apis::AgentregistryV1alpha::Operation::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['skillId'] = skill_id unless skill_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_skill_revision(parent, skill_revision_object = nil, request_id: nil, skill_revision_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Creates a new immutable revision and triggers validation pipelines.
1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 1459 def create_project_location_skill_revision(parent, skill_revision_object = nil, request_id: nil, skill_revision_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/revisions', ) command.request_representation = Google::Apis::AgentregistryV1alpha::SkillRevision::Representation command.request_object = skill_revision_object command.response_representation = Google::Apis::AgentregistryV1alpha::Operation::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['skillRevisionId'] = skill_revision_id unless skill_revision_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_binding(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Deletes a single Binding.
333 334 335 336 337 338 339 340 341 342 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 333 def delete_project_location_binding(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::AgentregistryV1alpha::Operation::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
769 770 771 772 773 774 775 776 777 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 769 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::AgentregistryV1alpha::Empty::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_service(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Deletes a single Service.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 1010 def delete_project_location_service(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::AgentregistryV1alpha::Operation::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_skill(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Deletes a Skill container along with all its revisions.
1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 1219 def delete_project_location_skill(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::AgentregistryV1alpha::Operation::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_skill_revision(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Deletes a specific revision (restricted to admins to purge accidentally committed secrets).
1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 1496 def delete_project_location_skill_revision(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::AgentregistryV1alpha::Operation::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#fetch_project_location_binding_available(parent, page_size: nil, page_token: nil, source_identifier: nil, target_identifier: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::FetchAvailableBindingsResponse
Fetches available Bindings.
377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 377 def fetch_project_location_binding_available(parent, page_size: nil, page_token: nil, source_identifier: nil, target_identifier: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/bindings:fetchAvailable', ) command.response_representation = Google::Apis::AgentregistryV1alpha::FetchAvailableBindingsResponse::Representation command.response_class = Google::Apis::AgentregistryV1alpha::FetchAvailableBindingsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['sourceIdentifier'] = source_identifier unless source_identifier.nil? command.query['targetIdentifier'] = target_identifier unless target_identifier.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Location
Gets information about a location.
76 77 78 79 80 81 82 83 84 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 76 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::AgentregistryV1alpha::Location::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_agent(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Agent
Gets details of a single Agent.
162 163 164 165 166 167 168 169 170 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 162 def get_project_location_agent(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::AgentregistryV1alpha::Agent::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Agent command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_binding(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Binding
Gets details of a single Binding.
412 413 414 415 416 417 418 419 420 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 412 def get_project_location_binding(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::AgentregistryV1alpha::Binding::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Binding command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_endpoint(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Endpoint
Gets details of a single Endpoint.
542 543 544 545 546 547 548 549 550 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 542 def get_project_location_endpoint(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::AgentregistryV1alpha::Endpoint::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Endpoint command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_mcp_server(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::McpServer
Gets details of a single McpServer.
618 619 620 621 622 623 624 625 626 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 618 def get_project_location_mcp_server(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::AgentregistryV1alpha::McpServer::Representation command.response_class = Google::Apis::AgentregistryV1alpha::McpServer command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
800 801 802 803 804 805 806 807 808 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 800 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::AgentregistryV1alpha::Operation::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_publisher(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Publisher
Fetches details of a specific Publisher.
880 881 882 883 884 885 886 887 888 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 880 def get_project_location_publisher(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::AgentregistryV1alpha::Publisher::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Publisher command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Service
Gets details of a single Service.
1042 1043 1044 1045 1046 1047 1048 1049 1050 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 1042 def get_project_location_service(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::AgentregistryV1alpha::Service::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Service command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_skill(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Skill
Fetches the active configuration and metadata of a Skill.
1251 1252 1253 1254 1255 1256 1257 1258 1259 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 1251 def get_project_location_skill(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::AgentregistryV1alpha::Skill::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Skill command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_skill_revision(name, fields: nil, quota_user: nil, download_dest: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::SkillRevision
Gets details of a single immutable Revision.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 1529 def get_project_location_skill_revision(name, fields: nil, quota_user: nil, download_dest: nil, options: nil, &block) if download_dest.nil? command = make_simple_command(:get, 'v1alpha/{+name}', ) else command = make_download_command(:get, 'v1alpha/{+name}', ) command.download_dest = download_dest end command.response_representation = Google::Apis::AgentregistryV1alpha::SkillRevision::Representation command.response_class = Google::Apis::AgentregistryV1alpha::SkillRevision command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_agents(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListAgentsResponse
Lists Agents in a given project and location.
201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 201 def list_project_location_agents(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/agents', ) command.response_representation = Google::Apis::AgentregistryV1alpha::ListAgentsResponse::Representation command.response_class = Google::Apis::AgentregistryV1alpha::ListAgentsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_bindings(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListBindingsResponse
Lists Bindings in a given project and location.
454 455 456 457 458 459 460 461 462 463 464 465 466 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 454 def list_project_location_bindings(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/bindings', ) command.response_representation = Google::Apis::AgentregistryV1alpha::ListBindingsResponse::Representation command.response_class = Google::Apis::AgentregistryV1alpha::ListBindingsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_endpoints(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListEndpointsResponse
Lists Endpoints in a given project and location.
585 586 587 588 589 590 591 592 593 594 595 596 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 585 def list_project_location_endpoints(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/endpoints', ) command.response_representation = Google::Apis::AgentregistryV1alpha::ListEndpointsResponse::Representation command.response_class = Google::Apis::AgentregistryV1alpha::ListEndpointsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_mcp_servers(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListMcpServersResponse
Lists McpServers in a given project and location.
658 659 660 661 662 663 664 665 666 667 668 669 670 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 658 def list_project_location_mcp_servers(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/mcpServers', ) command.response_representation = Google::Apis::AgentregistryV1alpha::ListMcpServersResponse::Representation command.response_class = Google::Apis::AgentregistryV1alpha::ListMcpServersResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
845 846 847 848 849 850 851 852 853 854 855 856 857 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 845 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}/operations', ) command.response_representation = Google::Apis::AgentregistryV1alpha::ListOperationsResponse::Representation command.response_class = Google::Apis::AgentregistryV1alpha::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_publishers(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListPublishersResponse
Lists all Publishers in a location.
915 916 917 918 919 920 921 922 923 924 925 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 915 def list_project_location_publishers(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/publishers', ) command.response_representation = Google::Apis::AgentregistryV1alpha::ListPublishersResponse::Representation command.response_class = Google::Apis::AgentregistryV1alpha::ListPublishersResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_services(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListServicesResponse
Lists Services in a given project and location.
1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 1084 def list_project_location_services(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/services', ) command.response_representation = Google::Apis::AgentregistryV1alpha::ListServicesResponse::Representation command.response_class = Google::Apis::AgentregistryV1alpha::ListServicesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_skill_revisions(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListSkillRevisionsResponse
Lists all revisions belonging to a parent Skill.
1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 1568 def list_project_location_skill_revisions(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/revisions', ) command.response_representation = Google::Apis::AgentregistryV1alpha::ListSkillRevisionsResponse::Representation command.response_class = Google::Apis::AgentregistryV1alpha::ListSkillRevisionsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_skills(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListSkillsResponse
Lists logical Skills available in a project.
1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 1297 def list_project_location_skills(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/skills', ) command.response_representation = Google::Apis::AgentregistryV1alpha::ListSkillsResponse::Representation command.response_class = Google::Apis::AgentregistryV1alpha::ListSkillsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 128 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}/locations', ) command.response_representation = Google::Apis::AgentregistryV1alpha::ListLocationsResponse::Representation command.response_class = Google::Apis::AgentregistryV1alpha::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_binding(name, binding_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Updates the parameters of a single Binding.
507 508 509 510 511 512 513 514 515 516 517 518 519 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 507 def patch_project_location_binding(name, binding_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/{+name}', ) command.request_representation = Google::Apis::AgentregistryV1alpha::Binding::Representation command.request_object = binding_object command.response_representation = Google::Apis::AgentregistryV1alpha::Operation::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_service(name, service_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Updates the parameters of a single Service.
1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 1136 def patch_project_location_service(name, service_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/{+name}', ) command.request_representation = Google::Apis::AgentregistryV1alpha::Service::Representation command.request_object = service_object command.response_representation = Google::Apis::AgentregistryV1alpha::Operation::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_skill(name, skill_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::Operation
Updates Skill metadata or overrides active pointers/state using REST standard PATCH.
1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 1341 def patch_project_location_skill(name, skill_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/{+name}', ) command.request_representation = Google::Apis::AgentregistryV1alpha::Skill::Representation command.request_object = skill_object command.response_representation = Google::Apis::AgentregistryV1alpha::Operation::Representation command.response_class = Google::Apis::AgentregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_agents(parent, search_agents_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::SearchAgentsResponse
Searches Agents in a given project and location.
237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 237 def search_agents(parent, search_agents_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/agents:search', ) command.request_representation = Google::Apis::AgentregistryV1alpha::SearchAgentsRequest::Representation command.request_object = search_agents_request_object command.response_representation = Google::Apis::AgentregistryV1alpha::SearchAgentsResponse::Representation command.response_class = Google::Apis::AgentregistryV1alpha::SearchAgentsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_mcp_servers(parent, search_mcp_servers_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::SearchMcpServersResponse
Searches McpServers in a given project and location.
694 695 696 697 698 699 700 701 702 703 704 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 694 def search_mcp_servers(parent, search_mcp_servers_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/mcpServers:search', ) command.request_representation = Google::Apis::AgentregistryV1alpha::SearchMcpServersRequest::Representation command.request_object = search_mcp_servers_request_object command.response_representation = Google::Apis::AgentregistryV1alpha::SearchMcpServersResponse::Representation command.response_class = Google::Apis::AgentregistryV1alpha::SearchMcpServersResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_project_location_skills(parent, filter: nil, page_size: nil, page_token: nil, search_string: nil, search_type: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentregistryV1alpha::SearchSkillsResponse
Custom deep-search method to filter by frontmatter or query SKILL.md text blobs.
1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 |
# File 'lib/google/apis/agentregistry_v1alpha/service.rb', line 1418 def search_project_location_skills(parent, filter: nil, page_size: nil, page_token: nil, search_string: nil, search_type: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/skills:search', ) command.response_representation = Google::Apis::AgentregistryV1alpha::SearchSkillsResponse::Representation command.response_class = Google::Apis::AgentregistryV1alpha::SearchSkillsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['searchString'] = search_string unless search_string.nil? command.query['searchType'] = search_type unless search_type.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |