Class: Google::Apis::AgentregistryV1alpha::AgentSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb

Overview

The spec of the agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AgentSpec

Returns a new instance of AgentSpec.



188
189
190
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 188

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentHash<String,Object>

Optional. The content of the Agent spec in the JSON format. This payload is validated against the schema for the specified type. The content size is limited to 10KB. Corresponds to the JSON property content

Returns:

  • (Hash<String,Object>)


181
182
183
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 181

def content
  @content
end

#typeString

Required. The type of the agent spec content. Corresponds to the JSON property type

Returns:

  • (String)


186
187
188
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 186

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



193
194
195
196
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 193

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @type = args[:type] if args.key?(:type)
end