Class: Google::Apis::AgentregistryV1alpha::Annotations

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb

Overview

Annotations describing the characteristics and behavior of a tool or operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Annotations

Returns a new instance of Annotations.



239
240
241
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 239

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destructive_hintBoolean Also known as: destructive_hint?

Output only. If true, the tool may perform destructive updates to its environment. If false, the tool performs only additive updates. NOTE: This property is meaningful only when read_only_hint == false Default: true Corresponds to the JSON property destructiveHint

Returns:

  • (Boolean)


208
209
210
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 208

def destructive_hint
  @destructive_hint
end

#idempotent_hintBoolean Also known as: idempotent_hint?

Output only. If true, calling the tool repeatedly with the same arguments will have no additional effect on its environment. NOTE: This property is meaningful only when read_only_hint == false Default: false Corresponds to the JSON property idempotentHint

Returns:

  • (Boolean)


216
217
218
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 216

def idempotent_hint
  @idempotent_hint
end

#open_world_hintBoolean Also known as: open_world_hint?

Output only. If true, this tool may interact with an "open world" of external entities. If false, the tool's domain of interaction is closed. For example, the world of a web search tool is open, whereas that of a memory tool is not. Default: true Corresponds to the JSON property openWorldHint

Returns:

  • (Boolean)


225
226
227
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 225

def open_world_hint
  @open_world_hint
end

#read_only_hintBoolean Also known as: read_only_hint?

Output only. If true, the tool does not modify its environment. Default: false Corresponds to the JSON property readOnlyHint

Returns:

  • (Boolean)


231
232
233
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 231

def read_only_hint
  @read_only_hint
end

#titleString

Output only. A human-readable title for the tool. Corresponds to the JSON property title

Returns:

  • (String)


237
238
239
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 237

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



244
245
246
247
248
249
250
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 244

def update!(**args)
  @destructive_hint = args[:destructive_hint] if args.key?(:destructive_hint)
  @idempotent_hint = args[:idempotent_hint] if args.key?(:idempotent_hint)
  @open_world_hint = args[:open_world_hint] if args.key?(:open_world_hint)
  @read_only_hint = args[:read_only_hint] if args.key?(:read_only_hint)
  @title = args[:title] if args.key?(:title)
end