Class: Google::Apis::AgentregistryV1alpha::FetchAvailableBindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AgentregistryV1alpha::FetchAvailableBindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb
Overview
Message for response to fetching available Bindings.
Instance Attribute Summary collapse
-
#bindings ⇒ Array<Google::Apis::AgentregistryV1alpha::Binding>
The list of Bindings.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FetchAvailableBindingsResponse
constructor
A new instance of FetchAvailableBindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FetchAvailableBindingsResponse
Returns a new instance of FetchAvailableBindingsResponse.
464 465 466 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 464 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bindings ⇒ Array<Google::Apis::AgentregistryV1alpha::Binding>
The list of Bindings.
Corresponds to the JSON property bindings
457 458 459 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 457 def bindings @bindings end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
462 463 464 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 462 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
469 470 471 472 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 469 def update!(**args) @bindings = args[:bindings] if args.key?(:bindings) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |