Class: Google::Apis::AgentregistryV1alpha::ListBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb

Overview

Message for response to listing Bindings

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBindingsResponse

Returns a new instance of ListBindingsResponse.



585
586
587
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bindingsArray<Google::Apis::AgentregistryV1alpha::Binding>

The list of Binding resources matching the parent and filter criteria in the request. Each Binding resource follows the format: projects/project/ locations/location/bindings/binding`. Corresponds to the JSON propertybindings`



577
578
579
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 577

def bindings
  @bindings
end

#next_page_tokenString

A token identifying a page of results the server should return. Used in page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


583
584
585
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 583

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



590
591
592
593
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 590

def update!(**args)
  @bindings = args[:bindings] if args.key?(:bindings)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end