Class: Google::Apis::AgentregistryV1alpha::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



653
654
655
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 653

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


638
639
640
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 638

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::AgentregistryV1alpha::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



643
644
645
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 643

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


651
652
653
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 651

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



658
659
660
661
662
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 658

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end