Class: Google::Apis::AgentregistryV1alpha::SearchMcpServersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb

Overview

Message for response to searching MCP Servers

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchMcpServersResponse

Returns a new instance of SearchMcpServersResponse.



1147
1148
1149
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1147

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mcp_serversArray<Google::Apis::AgentregistryV1alpha::McpServer>

A list of McpServers that match the search_string. Corresponds to the JSON property mcpServers



1138
1139
1140
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1138

def mcp_servers
  @mcp_servers
end

#next_page_tokenString

If there are more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1145
1146
1147
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1145

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1152
1153
1154
1155
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1152

def update!(**args)
  @mcp_servers = args[:mcp_servers] if args.key?(:mcp_servers)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end