Class: Google::Apis::AgentregistryV1alpha::Tool
- Inherits:
-
Object
- Object
- Google::Apis::AgentregistryV1alpha::Tool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb
Overview
Represents a single tool provided by an MCP Server.
Instance Attribute Summary collapse
-
#annotations ⇒ Google::Apis::AgentregistryV1alpha::Annotations
Annotations describing the characteristics and behavior of a tool or operation.
-
#description ⇒ String
Output only.
-
#name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Tool
constructor
A new instance of Tool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Tool
Returns a new instance of Tool.
1816 1817 1818 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Google::Apis::AgentregistryV1alpha::Annotations
Annotations describing the characteristics and behavior of a tool or operation.
Corresponds to the JSON property annotations
1804 1805 1806 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1804 def annotations @annotations end |
#description ⇒ String
Output only. Description of what the tool does.
Corresponds to the JSON property description
1809 1810 1811 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1809 def description @description end |
#name ⇒ String
Output only. Human-readable name of the tool.
Corresponds to the JSON property name
1814 1815 1816 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1814 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1821 1822 1823 1824 1825 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1821 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) end |