Class: Google::Apis::AgentregistryV1alpha::Agent
- Inherits:
-
Object
- Object
- Google::Apis::AgentregistryV1alpha::Agent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb
Overview
Represents an Agent. "A2A" below refers to the Agent-to-Agent protocol.
Instance Attribute Summary collapse
-
#agent_id ⇒ String
Output only.
-
#attributes ⇒ Hash<String,Hash<String,Object>>
Output only.
-
#card ⇒ Google::Apis::AgentregistryV1alpha::Card
Full Agent Card payload, often obtained from the A2A Agent Card.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#location ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#protocols ⇒ Array<Google::Apis::AgentregistryV1alpha::Protocol>
Output only.
-
#skills ⇒ Array<Google::Apis::AgentregistryV1alpha::A2ASkill>
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Agent
constructor
A new instance of Agent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Agent
Returns a new instance of Agent.
150 151 152 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 150 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
Output only. A stable, globally unique identifier for agents.
Corresponds to the JSON property agentId
75 76 77 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 75 def agent_id @agent_id end |
#attributes ⇒ Hash<String,Hash<String,Object>>
Output only. Attributes of the Agent. Valid values: * agentregistry.
googleapis.com/system/Framework: "framework": "google-adk" - the agent
framework used to develop the Agent. Example values: "google-adk", "langchain",
"custom". * agentregistry.googleapis.com/system/RuntimeIdentity: "
principal": "principal://..." - the runtime identity associated with the
Agent. * agentregistry.googleapis.com/system/RuntimeReference: "uri": "//...
" - the URI of the underlying resource hosting the Agent, for example, the
Reasoning Engine URI.
Corresponds to the JSON property attributes
87 88 89 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 87 def attributes @attributes end |
#card ⇒ Google::Apis::AgentregistryV1alpha::Card
Full Agent Card payload, often obtained from the A2A Agent Card.
Corresponds to the JSON property card
92 93 94 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 92 def card @card end |
#create_time ⇒ String
Output only. Create time.
Corresponds to the JSON property createTime
97 98 99 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 97 def create_time @create_time end |
#description ⇒ String
Output only. The description of the Agent, often obtained from the A2A Agent
Card. Empty if Agent Card has no description.
Corresponds to the JSON property description
103 104 105 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 103 def description @description end |
#display_name ⇒ String
Output only. The display name of the agent, often obtained from the A2A Agent
Card.
Corresponds to the JSON property displayName
109 110 111 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 109 def display_name @display_name end |
#location ⇒ String
Output only. The location where agent is hosted. The value is defined by the
hosting environment (i.e. cloud provider).
Corresponds to the JSON property location
115 116 117 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 115 def location @location end |
#name ⇒ String
Identifier. The resource name of an Agent. Format: projects/project/
locations/location/agents/agent`.
Corresponds to the JSON propertyname`
121 122 123 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 121 def name @name end |
#protocols ⇒ Array<Google::Apis::AgentregistryV1alpha::Protocol>
Output only. The connection details for the Agent.
Corresponds to the JSON property protocols
126 127 128 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 126 def protocols @protocols end |
#skills ⇒ Array<Google::Apis::AgentregistryV1alpha::A2ASkill>
Output only. Skills the agent possesses, often obtained from the A2A Agent
Card.
Corresponds to the JSON property skills
132 133 134 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 132 def skills @skills end |
#uid ⇒ String
Output only. A universally unique identifier for the Agent.
Corresponds to the JSON property uid
137 138 139 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 137 def uid @uid end |
#update_time ⇒ String
Output only. Update time.
Corresponds to the JSON property updateTime
142 143 144 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 142 def update_time @update_time end |
#version ⇒ String
Output only. The version of the Agent, often obtained from the A2A Agent Card.
Empty if Agent Card has no version or agent is not an A2A Agent.
Corresponds to the JSON property version
148 149 150 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 148 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 155 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @attributes = args[:attributes] if args.key?(:attributes) @card = args[:card] if args.key?(:card) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @protocols = args[:protocols] if args.key?(:protocols) @skills = args[:skills] if args.key?(:skills) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @version = args[:version] if args.key?(:version) end |