Class: Google::Apis::AgentregistryV1alpha::Agent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb

Overview

Represents an Agent. "A2A" below refers to the Agent-to-Agent protocol.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Agent

Returns a new instance of Agent.



107
108
109
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 107

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

Output only. A stable, globally unique identifier for agents. Corresponds to the JSON property agentId

Returns:

  • (String)


32
33
34
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 32

def agent_id
  @agent_id
end

#attributesHash<String,Hash<String,Object>>

Output only. Attributes of the Agent. Valid values: * agentregistry. googleapis.com/system/Framework: "framework": "google-adk" - the agent framework used to develop the Agent. Example values: "google-adk", "langchain", "custom". * agentregistry.googleapis.com/system/RuntimeIdentity: " principal": "principal://..." - the runtime identity associated with the Agent. * agentregistry.googleapis.com/system/RuntimeReference: "uri": "//... " - the URI of the underlying resource hosting the Agent, for example, the Reasoning Engine URI. Corresponds to the JSON property attributes

Returns:

  • (Hash<String,Hash<String,Object>>)


44
45
46
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 44

def attributes
  @attributes
end

#cardGoogle::Apis::AgentregistryV1alpha::Card

Full Agent Card payload, often obtained from the A2A Agent Card. Corresponds to the JSON property card



49
50
51
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 49

def card
  @card
end

#create_timeString

Output only. Create time. Corresponds to the JSON property createTime

Returns:

  • (String)


54
55
56
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 54

def create_time
  @create_time
end

#descriptionString

Output only. The description of the Agent, often obtained from the A2A Agent Card. Empty if Agent Card has no description. Corresponds to the JSON property description

Returns:

  • (String)


60
61
62
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 60

def description
  @description
end

#display_nameString

Output only. The display name of the agent, often obtained from the A2A Agent Card. Corresponds to the JSON property displayName

Returns:

  • (String)


66
67
68
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 66

def display_name
  @display_name
end

#locationString

Output only. The location where agent is hosted. The value is defined by the hosting environment (i.e. cloud provider). Corresponds to the JSON property location

Returns:

  • (String)


72
73
74
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 72

def location
  @location
end

#nameString

Identifier. The resource name of an Agent. Format: projects/project/ locations/location/agents/agent`. Corresponds to the JSON propertyname`

Returns:

  • (String)


78
79
80
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 78

def name
  @name
end

#protocolsArray<Google::Apis::AgentregistryV1alpha::Protocol>

Output only. The connection details for the Agent. Corresponds to the JSON property protocols



83
84
85
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 83

def protocols
  @protocols
end

#skillsArray<Google::Apis::AgentregistryV1alpha::Skill>

Output only. Skills the agent possesses, often obtained from the A2A Agent Card. Corresponds to the JSON property skills



89
90
91
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 89

def skills
  @skills
end

#uidString

Output only. A universally unique identifier for the Agent. Corresponds to the JSON property uid

Returns:

  • (String)


94
95
96
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 94

def uid
  @uid
end

#update_timeString

Output only. Update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


99
100
101
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 99

def update_time
  @update_time
end

#versionString

Output only. The version of the Agent, often obtained from the A2A Agent Card. Empty if Agent Card has no version or agent is not an A2A Agent. Corresponds to the JSON property version

Returns:

  • (String)


105
106
107
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 105

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 112

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @attributes = args[:attributes] if args.key?(:attributes)
  @card = args[:card] if args.key?(:card)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @protocols = args[:protocols] if args.key?(:protocols)
  @skills = args[:skills] if args.key?(:skills)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version = args[:version] if args.key?(:version)
end