Class: Google::Apis::AgentregistryV1alpha::Annotations

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb

Overview

Annotations describing the characteristics and behavior of a tool or operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Annotations

Returns a new instance of Annotations.



196
197
198
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 196

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destructive_hintBoolean Also known as: destructive_hint?

Output only. If true, the tool may perform destructive updates to its environment. If false, the tool performs only additive updates. NOTE: This property is meaningful only when read_only_hint == false Default: true Corresponds to the JSON property destructiveHint

Returns:

  • (Boolean)


165
166
167
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 165

def destructive_hint
  @destructive_hint
end

#idempotent_hintBoolean Also known as: idempotent_hint?

Output only. If true, calling the tool repeatedly with the same arguments will have no additional effect on its environment. NOTE: This property is meaningful only when read_only_hint == false Default: false Corresponds to the JSON property idempotentHint

Returns:

  • (Boolean)


173
174
175
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 173

def idempotent_hint
  @idempotent_hint
end

#open_world_hintBoolean Also known as: open_world_hint?

Output only. If true, this tool may interact with an "open world" of external entities. If false, the tool's domain of interaction is closed. For example, the world of a web search tool is open, whereas that of a memory tool is not. Default: true Corresponds to the JSON property openWorldHint

Returns:

  • (Boolean)


182
183
184
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 182

def open_world_hint
  @open_world_hint
end

#read_only_hintBoolean Also known as: read_only_hint?

Output only. If true, the tool does not modify its environment. Default: false Corresponds to the JSON property readOnlyHint

Returns:

  • (Boolean)


188
189
190
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 188

def read_only_hint
  @read_only_hint
end

#titleString

Output only. A human-readable title for the tool. Corresponds to the JSON property title

Returns:

  • (String)


194
195
196
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 194

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



201
202
203
204
205
206
207
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 201

def update!(**args)
  @destructive_hint = args[:destructive_hint] if args.key?(:destructive_hint)
  @idempotent_hint = args[:idempotent_hint] if args.key?(:idempotent_hint)
  @open_world_hint = args[:open_world_hint] if args.key?(:open_world_hint)
  @read_only_hint = args[:read_only_hint] if args.key?(:read_only_hint)
  @title = args[:title] if args.key?(:title)
end