Class: Google::Apis::AgentregistryV1alpha::ListBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb

Overview

Message for response to listing Bindings

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBindingsResponse

Returns a new instance of ListBindingsResponse.



542
543
544
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 542

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bindingsArray<Google::Apis::AgentregistryV1alpha::Binding>

The list of Binding resources matching the parent and filter criteria in the request. Each Binding resource follows the format: projects/project/ locations/location/bindings/binding`. Corresponds to the JSON propertybindings`



534
535
536
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 534

def bindings
  @bindings
end

#next_page_tokenString

A token identifying a page of results the server should return. Used in page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


540
541
542
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 540

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



547
548
549
550
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 547

def update!(**args)
  @bindings = args[:bindings] if args.key?(:bindings)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end