Class: Google::Apis::AgentregistryV1alpha::ListServicesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AgentregistryV1alpha::ListServicesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb
Overview
Message for response to listing Services
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#services ⇒ Array<Google::Apis::AgentregistryV1alpha::Service>
The list of Service resources matching the parent and filter criteria in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListServicesResponse
constructor
A new instance of ListServicesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListServicesResponse
Returns a new instance of ListServicesResponse.
682 683 684 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 682 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return. Used in
page_token.
Corresponds to the JSON property nextPageToken
673 674 675 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 673 def next_page_token @next_page_token end |
#services ⇒ Array<Google::Apis::AgentregistryV1alpha::Service>
The list of Service resources matching the parent and filter criteria in the
request. Each Service resource follows the format: projects/project/
locations/location/services/service`.
Corresponds to the JSON propertyservices`
680 681 682 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 680 def services @services end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
687 688 689 690 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 687 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @services = args[:services] if args.key?(:services) end |