Class: Google::Apis::AgentregistryV1alpha::SearchAgentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb

Overview

Message for searching Agents

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchAgentsRequest

Returns a new instance of SearchAgentsRequest.



1037
1038
1039
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1037

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#page_sizeFixnum

Optional. The maximum number of search results to return per page. The page size is capped at 100, even if a larger value is specified. A negative value will result in an INVALID_ARGUMENT error. If unspecified or set to 0, a default value of 20 will be used. The server may return fewer results than requested. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


1003
1004
1005
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1003

def page_size
  @page_size
end

#page_tokenString

Optional. If present, retrieve the next batch of results from the preceding call to this method. page_token must be the value of next_page_token from the previous response. The values of all other method parameters, must be identical to those in the previous call. Corresponds to the JSON property pageToken

Returns:

  • (String)


1011
1012
1013
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1011

def page_token
  @page_token
end

#search_stringString

Optional. Search criteria used to select the Agents to return. If no search criteria is specified then all accessible Agents will be returned. Search expressions can be used to restrict results based upon searchable fields, where the operators can be used along with the suffix wildcard symbol *. See instructions for more details. Allowed operators: =, :, NOT, AND, OR, and (). Searchable fields: | Field | = | : | * | Keyword Search | |--------- -----------|-----|-----|-----|----------------| | agentId | Yes | Yes | Yes | Included | | name | No | Yes | Yes | Included | | displayName | No | Yes | Yes | Included | | description | No | Yes | No | Included | | skills | No | Yes | No | Included | | skills.id | No | Yes | No | Included | | skills.name | No | Yes | No | Included | | skills.description | No | Yes | No | Included | | skills.tags | No | Yes | No | Included | | skills.examples | No | Yes | No | Included | Examples: * agentId=urn:agent:projects-123:projects:123:locations: us-central1:reasoningEngines:1234 to find the agent with the specified agent ID. * name:important to find agents whose name contains important as a word. * displayName:works* to find agents whose display name contains words that start with works. * skills.tags:test to find agents whose skills tags contain test. * planner OR booking to find agents whose metadata contains the words planner or booking. Corresponds to the JSON property searchString

Returns:

  • (String)


1035
1036
1037
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1035

def search_string
  @search_string
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1042
1043
1044
1045
1046
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1042

def update!(**args)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @search_string = args[:search_string] if args.key?(:search_string)
end