Class: Google::Apis::AgentregistryV1alpha::SearchAgentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AgentregistryV1alpha::SearchAgentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb
Overview
Message for response to searching Agents
Instance Attribute Summary collapse
-
#agents ⇒ Array<Google::Apis::AgentregistryV1alpha::Agent>
A list of Agents that match the
search_string. -
#next_page_token ⇒ String
If there are more results than those appearing in this response, then
next_page_tokenis included.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchAgentsResponse
constructor
A new instance of SearchAgentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchAgentsResponse
Returns a new instance of SearchAgentsResponse.
1065 1066 1067 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1065 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agents ⇒ Array<Google::Apis::AgentregistryV1alpha::Agent>
A list of Agents that match the search_string.
Corresponds to the JSON property agents
1056 1057 1058 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1056 def agents @agents end |
#next_page_token ⇒ String
If there are more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this method
again using the value of next_page_token as page_token.
Corresponds to the JSON property nextPageToken
1063 1064 1065 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1063 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1070 1071 1072 1073 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1070 def update!(**args) @agents = args[:agents] if args.key?(:agents) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |