Class: Google::Apis::AgentregistryV1alpha::SearchMcpServersRequest
- Inherits:
-
Object
- Object
- Google::Apis::AgentregistryV1alpha::SearchMcpServersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb
Overview
Message for searching MCP Servers
Instance Attribute Summary collapse
-
#page_size ⇒ Fixnum
Optional.
-
#page_token ⇒ String
Optional.
-
#search_string ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchMcpServersRequest
constructor
A new instance of SearchMcpServersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchMcpServersRequest
Returns a new instance of SearchMcpServersRequest.
1162 1163 1164 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_size ⇒ Fixnum
Optional. The maximum number of search results to return per page. The page
size is capped at 100, even if a larger value is specified. A negative value
will result in an INVALID_ARGUMENT error. If unspecified or set to 0, a
default value of 20 will be used. The server may return fewer results than
requested.
Corresponds to the JSON property pageSize
1130 1131 1132 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1130 def page_size @page_size end |
#page_token ⇒ String
Optional. If present, retrieve the next batch of results from the preceding
call to this method. page_token must be the value of next_page_token from
the previous response. The values of all other method parameters, must be
identical to those in the previous call.
Corresponds to the JSON property pageToken
1138 1139 1140 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1138 def page_token @page_token end |
#search_string ⇒ String
Optional. Search criteria used to select the MCP Servers to return. If no
search criteria is specified then all accessible MCP Servers will be returned.
Search expressions can be used to restrict results based upon searchable
fields, where the operators can be used along with the suffix wildcard symbol
*. See instructions for more details. Allowed operators: =, :, NOT, AND,
OR, and (). Searchable fields: | Field | = | : | * | Keyword Search |
|--------------------|-----|-----|-----|----------------| | mcpServerId | Yes
| Yes | Yes | Included | | name | No | Yes | Yes | Included | | displayName |
No | Yes | Yes | Included | Examples: * mcpServerId="urn:mcp:projects-123:
projects:123:locations:us-central1:agentregistry:services:service-id" to find
the MCP Server with the specified MCP Server ID. * name:important to find
MCP Servers whose name contains important as a word. * displayName:works*
to find MCP Servers whose display name contains words that start with works.
planner OR bookingto find MCP Servers whose metadata contains the wordsplannerorbooking. *mcpServerId:service-id AND (displayName:planner OR displayName:booking)to find MCP Servers whose MCP Server ID containsservice-idand whose display name containsplannerorbooking. Corresponds to the JSON propertysearchString
1160 1161 1162 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1160 def search_string @search_string end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1167 1168 1169 1170 1171 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1167 def update!(**args) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @search_string = args[:search_string] if args.key?(:search_string) end |