Class: Google::Apis::AgentregistryV1alpha::Skill
- Inherits:
-
Object
- Object
- Google::Apis::AgentregistryV1alpha::Skill
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb
Overview
Represents an Executable Agent Skill or a Composite Tool Suite (Bundle). Sibling resource with Agent and McpServer under agentregistry.googleapis.com.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#default_revision ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#frontmatter ⇒ Google::Apis::AgentregistryV1alpha::Frontmatter
Structured metadata attributes extracted from the package's local SKILL.md frontmatter.
-
#initial_revision ⇒ Google::Apis::AgentregistryV1alpha::SkillRevision
Represents an immutable, versioned snapshot of a Skill package.
-
#name ⇒ String
Identifier.
-
#publisher ⇒ String
Optional.
-
#skill_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#target_state ⇒ String
Required.
-
#type ⇒ String
Required.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Skill
constructor
A new instance of Skill.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Skill
Returns a new instance of Skill.
1623 1624 1625 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1623 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Create time.
Corresponds to the JSON property createTime
1539 1540 1541 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1539 def create_time @create_time end |
#default_revision ⇒ String
Optional. The full resource name of the revision currently served by default (
floating track). Format: projects/project/locations/location/skills/
skill/revisions/revision`
Corresponds to the JSON propertydefaultRevision`
1546 1547 1548 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1546 def default_revision @default_revision end |
#description ⇒ String
Optional. Brief summary describing the capabilities of the skill. Maximum
length is 2048 characters.
Corresponds to the JSON property description
1552 1553 1554 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1552 def description @description end |
#display_name ⇒ String
Required. Human-readable display name of the skill. Maximum length is 128
characters.
Corresponds to the JSON property displayName
1558 1559 1560 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1558 def display_name @display_name end |
#frontmatter ⇒ Google::Apis::AgentregistryV1alpha::Frontmatter
Structured metadata attributes extracted from the package's local SKILL.md
frontmatter.
Corresponds to the JSON property frontmatter
1564 1565 1566 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1564 def frontmatter @frontmatter end |
#initial_revision ⇒ Google::Apis::AgentregistryV1alpha::SkillRevision
Represents an immutable, versioned snapshot of a Skill package.
Corresponds to the JSON property initialRevision
1569 1570 1571 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1569 def initial_revision @initial_revision end |
#name ⇒ String
Identifier. Resource name of the Skill. Format: projects/project/locations/
location/skills/skillTheskill`segment acts as the resource ID. If
the skill is associated with a Publisher, this segment typically uses a
hyphenated namespace prefix corresponding to the publisher (e.g.,google-
workspace-create-docs).
Corresponds to the JSON propertyname`
1578 1579 1580 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1578 def name @name end |
#publisher ⇒ String
Optional. The publisher resource associated with this skill. Format: projects/
project/locations/location/publishers/publisher`The publisher dictates
the allowed namespace prefixes for the skill's name and logicalskill_id(e.
g., Publishergoogleauthorizes thegoogle-*prefix).
Corresponds to the JSON propertypublisher`
1586 1587 1588 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1586 def publisher @publisher end |
#skill_id ⇒ String
Output only. A stable, globally unique logical identifier for the skill. It is
securely constructed by the backend by combining the associated publisher's
verified namespace and the skill's resource ID to enforce strict ownership.
For example, the prefix google- is reserved exclusively for first-party
Google publishers to prevent namespace squatting. Example: urn:skill:google-
workspace:create-docs
Corresponds to the JSON property skillId
1596 1597 1598 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1596 def skill_id @skill_id end |
#state ⇒ String
Output only. The system-managed state of the skill.
Corresponds to the JSON property state
1601 1602 1603 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1601 def state @state end |
#target_state ⇒ String
Required. User-managed target state of the skill.
Corresponds to the JSON property targetState
1606 1607 1608 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1606 def target_state @target_state end |
#type ⇒ String
Required. Structural deployment type (SIMPLE leaf vs COMPOSITE bundle).
Corresponds to the JSON property type
1611 1612 1613 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1611 def type @type end |
#uid ⇒ String
Output only. Universally unique identifier (UUID4) for the logical container.
Corresponds to the JSON property uid
1616 1617 1618 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1616 def uid @uid end |
#update_time ⇒ String
Output only. Update time.
Corresponds to the JSON property updateTime
1621 1622 1623 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1621 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1628 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @default_revision = args[:default_revision] if args.key?(:default_revision) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @frontmatter = args[:frontmatter] if args.key?(:frontmatter) @initial_revision = args[:initial_revision] if args.key?(:initial_revision) @name = args[:name] if args.key?(:name) @publisher = args[:publisher] if args.key?(:publisher) @skill_id = args[:skill_id] if args.key?(:skill_id) @state = args[:state] if args.key?(:state) @target_state = args[:target_state] if args.key?(:target_state) @type = args[:type] if args.key?(:type) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |