Class: Google::Apis::AgentregistryV1alpha::SkillRevision
- Inherits:
-
Object
- Object
- Google::Apis::AgentregistryV1alpha::SkillRevision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb
Overview
Represents an immutable, versioned snapshot of a Skill package.
Instance Attribute Summary collapse
-
#archive_upload_source ⇒ Google::Apis::AgentregistryV1alpha::ArchiveUploadSource
Direct write-only raw archive payload upload.
-
#create_time ⇒ String
Output only.
-
#frontmatter ⇒ Google::Apis::AgentregistryV1alpha::Frontmatter
Structured metadata attributes extracted from the package's local SKILL.md frontmatter.
-
#gcs_source ⇒ Google::Apis::AgentregistryV1alpha::GcsSource
Specifications for Cloud Storage objects.
-
#name ⇒ String
Identifier.
-
#sha256_hash ⇒ String
Output only.
-
#size_bytes ⇒ Fixnum
Output only.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SkillRevision
constructor
A new instance of SkillRevision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SkillRevision
Returns a new instance of SkillRevision.
1699 1700 1701 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1699 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive_upload_source ⇒ Google::Apis::AgentregistryV1alpha::ArchiveUploadSource
Direct write-only raw archive payload upload.
Corresponds to the JSON property archiveUploadSource
1653 1654 1655 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1653 def archive_upload_source @archive_upload_source end |
#create_time ⇒ String
Output only. Revision creation timestamp.
Corresponds to the JSON property createTime
1658 1659 1660 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1658 def create_time @create_time end |
#frontmatter ⇒ Google::Apis::AgentregistryV1alpha::Frontmatter
Structured metadata attributes extracted from the package's local SKILL.md
frontmatter.
Corresponds to the JSON property frontmatter
1664 1665 1666 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1664 def frontmatter @frontmatter end |
#gcs_source ⇒ Google::Apis::AgentregistryV1alpha::GcsSource
Specifications for Cloud Storage objects.
Corresponds to the JSON property gcsSource
1669 1670 1671 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1669 def gcs_source @gcs_source end |
#name ⇒ String
Identifier. Resource name of the SkillRevision. Format: projects/project/
locations/location/skills/skill/revisions/revision`
Corresponds to the JSON propertyname`
1675 1676 1677 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1675 def name @name end |
#sha256_hash ⇒ String
Output only. Cryptographic SHA-256 integrity and deduplication digest of the
payload zip.
Corresponds to the JSON property sha256Hash
1681 1682 1683 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1681 def sha256_hash @sha256_hash end |
#size_bytes ⇒ Fixnum
Output only. Size of the compiled zip payload in bytes (assists client
download progress).
Corresponds to the JSON property sizeBytes
1687 1688 1689 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1687 def size_bytes @size_bytes end |
#state ⇒ String
Output only. The system-managed lifecycle state of this revision.
Corresponds to the JSON property state
1692 1693 1694 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1692 def state @state end |
#uid ⇒ String
Output only. Universally unique identifier (UUID4) for the skill revision.
Corresponds to the JSON property uid
1697 1698 1699 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1697 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1704 def update!(**args) @archive_upload_source = args[:archive_upload_source] if args.key?(:archive_upload_source) @create_time = args[:create_time] if args.key?(:create_time) @frontmatter = args[:frontmatter] if args.key?(:frontmatter) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @name = args[:name] if args.key?(:name) @sha256_hash = args[:sha256_hash] if args.key?(:sha256_hash) @size_bytes = args[:size_bytes] if args.key?(:size_bytes) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) end |