Class: Google::Apis::AgentregistryV1alpha::Tool
- Inherits:
-
Object
- Object
- Google::Apis::AgentregistryV1alpha::Tool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentregistry_v1alpha/classes.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb,
lib/google/apis/agentregistry_v1alpha/representations.rb
Overview
Represents a single tool provided by an MCP Server.
Instance Attribute Summary collapse
-
#annotations ⇒ Google::Apis::AgentregistryV1alpha::Annotations
Annotations describing the characteristics and behavior of a tool or operation.
-
#description ⇒ String
Output only.
-
#name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Tool
constructor
A new instance of Tool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Tool
Returns a new instance of Tool.
1379 1380 1381 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Google::Apis::AgentregistryV1alpha::Annotations
Annotations describing the characteristics and behavior of a tool or operation.
Corresponds to the JSON property annotations
1367 1368 1369 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1367 def annotations @annotations end |
#description ⇒ String
Output only. Description of what the tool does.
Corresponds to the JSON property description
1372 1373 1374 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1372 def description @description end |
#name ⇒ String
Output only. Human-readable name of the tool.
Corresponds to the JSON property name
1377 1378 1379 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1377 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1384 1385 1386 1387 1388 |
# File 'lib/google/apis/agentregistry_v1alpha/classes.rb', line 1384 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) end |